# Dinasour

Chrome T-Rex's clone in Python 3 using __pyxel__ library.

Avoid enemies with __SPACE__ key.

![play](https://raw.githubusercontent.com/dannyso16/pynasour/master/media/readme.gif)

## Installation

```bash
# Python>=3.6.8
pip install pynasour
```

## Features

- SFX and BGM (New!)
- High score is kept
- feel free to use sprite

![sprite](https://raw.githubusercontent.com/dannyso16/pynasour/master/media/sprite.gif)
